@@ -4,6 +4,7 @@ from flask.ext.babel import gettext as _gettext
 from .security.views import AuthView, ResetPasswordView, UserGeneralView, RoleGeneralView, PermissionViewGeneralView, ViewMenuGeneralView, PermissionGeneralView, IndexView, PermissionView
 from .babel.views import LocaleView
 from menu import Menu
+from filters import TemplateFilters
 
 class BaseApp():
 
@@ -16,6 +17,8 @@ class BaseApp():
     static_folder = None
     static_url_path = None
     
+    template_filters = None
+    
     languages = None
     admin = None
     _gettext = _gettext
@@ -36,9 +39,18 @@ class BaseApp():
         self.static_folder = static_folder
         self.static_url_path = static_url_path
         self._add_admin_views()
-        
+        self.add_global_static()
+        self.add_global_filters()
+    
+    def add_global_filters(self):
+        self.template_filters = TemplateFilters(self.app)
+	
+    def add_global_static(self):
+        bp = Blueprint('baseapp', __name__, url_prefix='/static',
+                template_folder='templates', static_folder = self.static_folder, static_url_path = self.static_url_path)
+        self.app.register_blueprint(bp)
 
-    def _add_admin_views(self, ):
+    def _add_admin_views(self):
         self.add_view_no_menu(self.indexview)
         self.add_view_no_menu(LocaleView)
         self.add_view_no_menu(AuthView)
@@ -53,10 +65,7 @@ class BaseApp():
         self.add_view(ViewMenuGeneralView, "Views/Menus","/viewmenus/list","list-alt","Security")
         self.add_view(PermissionGeneralView, "Permission on Views/Menus","/permissionviews/list","lock","Security")
 
-        bp = Blueprint('baseapp', __name__, url_prefix='/static',
-                template_folder='templates', static_folder = self.static_folder, static_url_path = self.static_url_path)
-        self.app.register_blueprint(bp)
-
+        
     def add_view(self, baseview, name, href, icon, category):
         print "Registering:", category,".", name, "at", href
         self.menu.add_link(name, href, icon, category)
